# Emu86
This project will emulate an x86 assembler in Python, as a learning tool for students.

This project has now been expanded to emulating x86 assembler in Jupyter notebooks: [Emu86 Kernel](https://github.com/gcallah/Emu86/blob/master/kernels/README.md)
